@@ -66,7 +66,7 @@ class StopBuild(BzrError):
 
 
 class MissingChangelogError(BzrError):
-    _fmt = 'Could not find changelog at %(locations)s.'
+    _fmt = 'Could not find changelog at %(location)s.'
 
     def __init__(self, locations):
         BzrError.__init__(self, location=locations)
@@ -142,17 +142,18 @@ class UnknownVersion(BzrError):
         BzrError.__init__(self, version=version)
 
 
-class UnknownDistribution(BzrError):
-    _fmt = "Unknown distribution: %(distribution)s."
-
-    def __init__(self, distribution):
-        BzrError.__init__(self, distribution=distribution)
-
-
 class VersionNotSpecified(BzrError):
     _fmt = "You did not specify a package version."
 
 
+class PackageVersionNotPresent(BzrError):
+    _fmt = "%(package)s %(version)s was not found in %(upstream)s."
+
+    def __init__(self, package, version, upstream):
+        BzrError.__init__(self, package=package, version=version, 
+                          upstream=upstream)
+
+
 class UnsupportedRepackFormat(BzrError):
     _fmt = ('Either the file extension of "%(location)s" indicates that '
             'it is a format unsupported for repacking or it is a '
@@ -167,3 +168,59 @@ class PristineTarError(BzrError):
 
     def __init__(self, error):
         BzrError.__init__(self, error=error)
+
+
+class SharedUpstreamConflictsWithTargetPackaging(BzrError):
+    _fmt = ('The upstream branches for the merge source and target have '
+            'diverged. Unfortunately, the attempt to fix this problem '
+            'resulted in conflicts. Please resolve these, commit and '
+            're-run the "merge-package" command to finish. '
+            'Alternatively, until you commit you can use "bzr revert" to '
+            'restore the state of the unmerged branch.')
+
+
+class PerFileTimestampsNotSupported(BzrError):
+
+    _fmt = ("Per file timestamps are not supported by the "
+            "currently loaded version of bzrlib.")
+
+
+class NoPreviousUpload(BzrError):
+
+    _fmt = ("There was no previous upload to %(distribution)s.")
+
+    def __init__(self, distribution):
+        BzrError.__init__(self, distribution=distribution)
+
+
+class UnableToFindPreviousUpload(BzrError):
+
+    _fmt = ("Unable to determine the previous upload for --package-merge.")
+
+
+class InconsistentSourceFormatError(BzrError):
+
+    _fmt = ("Inconsistency between source format and version: version is "
+            "%(version_bool)snative, format is %(format_bool)snative.")
+
+    def __init__(self, version_native, format_native):
+        if version_native:
+            version_bool = ""
+        else:
+            version_bool = "not "
+        if format_native:
+            format_bool = ""
+        else:
+            format_bool = "not "
+        BzrError.__init__(self, version_bool=version_bool, format_bool=format_bool)
+
+
+class WatchFileMissing(BzrError):
+
+    _fmt = "No watch file found."
+
+
+class StrictBuildFailed(BzrError):
+
+    _fmt = ("Build refused because there are unknown files in the tree. "
+            "To list all known files, run 'bzr unknowns'.")
