@@ -21,15 +21,16 @@
 from bzrlib.tests import TestUtil
 
 
-def test_suite():
+def load_tests(standard_tests, module, loader):
   testmod_names = [
           'test_builddeb',
           'test_do',
           'test_import_dsc',
+          'test_import_upstream',
           'test_mark_uploaded',
+          'test_merge_package',
           'test_merge_upstream',
           ]
-  loader = TestUtil.TestLoader()
   suite = loader.loadTestsFromModuleNames(["%s.%s" % (__name__, i)
                                        for i in testmod_names])
   return suite
